pub struct MatrixDnsResolver { /* private fields */ }Expand description
A custom DNS resolver for reqwest that handles Matrix server name resolution.
This resolver integrates with the MatrixResolver cache and logic to ensure that
HTTP requests made by reqwest are routed to the correct IP address and port
as discovered by the Matrix server discovery process.
It exists to ensure that the correct SNI is used. The resolver base URL is the
domain expected for SNI, and the MatrixDnsResolver resolves it to the correct destination.